@@ -78,7 +78,7 @@ def create_virtual_env(path, environment='env'):
 def create_requirementes_txt(path, environment):
     try:
         if sys.platform.startswith('win'):
-            os.system(f"cd {path} && . {environment}\Scripts\activate && pip freeze > requirements.txt")
+            os.system(f"cd {path} && {environment}\Scripts\activate && pip freeze > requirements.txt")
         else:
             os.system(f"cd {path} && . {environment}/bin/activate && pip freeze > requirements.txt")
     except Exception as err:
